@@ -1,3 +1,4 @@
 from .version import __version__
-from .model import EnodoModel, EnodoModelArgument
+from .model import EnodoModule, EnodoModuleArgument
 from .model.config.worker import WorkerConfigModel
+from .worker import Worker
